/*
 * AirPlace:  The Airplace Project is an OpenSource Indoor and Outdoor
 * Localization solution using WiFi RSS (Receive Signal Strength).
 * The AirPlace Project consists of three parts:
 *
 *  1) The AirPlace Logger (Ideal for collecting RSS Logs)
 *  2) The AirPlace Server (Ideal for transforming the collected RSS logs
 *  to meaningful RadioMap files)
 *  3) The AirPlace Tracker (Ideal for using the RadioMap files for
 *  indoor localization)
 *
 * It is ideal for spaces where GPS signal is not sufficient.
 *
 * Authors:
 * C. Laoudias, G.Larkou, G. Constantinou, M. Constantinides, S. Nicolaou,
 *
 * Supervisors:
 * D. Zeinalipour-Yazti and C. G. Panayiotou
 *
 * Copyright (c) 2011, KIOS Research Center and Data Management Systems Lab (DMSL),
 * University of Cyprus. All rights reserved.
 *
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * Υou should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package cy.com.movement;

import java.util.ArrayList;

/**
 * 
 * @author Kyriakos Georgiou
 * @author 
 *         https://github.com/bagilevi/android-pedometer/blob/master/src/name/bagi
 *         /levente/pedometer/StepDisplayer.java
 * 
 */
public class MovementDisplayer implements MovementListener {

	public MovementDisplayer() {
	}

	@Override
	public void onWalking() {
		notifyListener(MovementDetector.MovementState.WALKING);
	}

	@Override
	public void onStanding() {
		notifyListener(MovementDetector.MovementState.STANDING);
	}

	public interface Listener {
		public void movementStanding();

		public void movementWalking();
	}

	private ArrayList<Listener> mListeners = new ArrayList<Listener>();

	public void addListener(Listener l) {
		mListeners.add(l);
	}

	public void notifyListener(MovementDetector.MovementState type) {
		switch (type) {
		case STANDING:
			for (Listener listener : mListeners) {
				listener.movementStanding();
			}
			break;
		case WALKING:
			for (Listener listener : mListeners) {
				listener.movementWalking();
			}
			break;
		}

	}

}